@@ -24,7 +24,7 @@
 #define MP4V2_PROJECT_repo_rev        493
 #define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
 #define MP4V2_PROJECT_repo_type       "stable"
-#define MP4V2_PROJECT_build           "Thu Dec 10 18:24:05 MST 2015"
+#define MP4V2_PROJECT_build           "Wed May 30 23:30:56 UTC 2018"
 
 /*****************************************************************************/
 
